//
//  Call.m
//  CallChecker
//
//  Created by Steffen Kamp on Mon Oct 21 2002.
//  <mailto:steffen@earthlingsoft.net>
//  Copyright (c) 2002 earthlingsoft. All rights reserved.
//

/*
 This file is part of CallChecker.

 CallChecker is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation; either version 2 of the License, or
 (at your option) any later version.

 CallChecker is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

 You should have received a copy of the GNU General Public License
 along with CallChecker; if not, write to the Free Software
 Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  US
 */

#import "Call.h"


@implementation Call

+ (id)callFromString:(NSString *)string {
    return [[[self alloc] initFromString:string] autorelease];
}
- (id)initFromString:(NSString *)string {
    self = [self init];
    if(self) {
        int day, month, year, hour, minute, second;
        NSScanner *scnr = [NSScanner scannerWithString:string];
        [scnr setCharactersToBeSkipped:[NSCharacterSet characterSetWithCharactersInString:@"/: "]];
        if(![scnr scanInt:&year]
           || ![scnr scanInt:&month]
           || ![scnr scanInt:&day]
           || ![scnr scanInt:&hour]
           || ![scnr scanInt:&minute]
           || ![scnr scanInt:&second]
           || ![scnr scanUpToString:@" " intoString:&_callerID]
           || ![scnr scanUpToString:@"\r" intoString:&_msn]) {
            [self release];
            return nil;
        }
        
        [_msn retain];
        [_callerID retain];
    
        _date = [[NSCalendarDate dateWithYear:year
                                      month:month
                                        day:day
                                       hour:hour
                                     minute:minute
                                     second:second
                                   timeZone:[NSTimeZone localTimeZone]] retain];

        _timestamp = [[NSCalendarDate calendarDate] retain];
    }
    return self;
}

- (void)dealloc {
    [_msn release];
    [_callerID release];
    [_date release];
    [_timestamp release];
    [super dealloc];
}


#pragma mark ----- Accessors -----

- (NSString *)msn {
    return _msn;
}
- (NSString *)callerID {
    return _callerID;
}
- (NSString *)callerName {
    return nil;
}
- (NSCalendarDate *)date {
    return _date;
}
- (NSCalendarDate *)timestamp {
    return _timestamp;
}

@end
