//
//  CallController.m
//  CallChecker
//
//  Created by Steffen Kamp on Mon Oct 19 2002.
//  <mailto:steffen@earthlingsoft.net>
//  Copyright (c) 2002 earthlingsoft. All rights reserved.
//

/*
 This file is part of CallChecker.

 CallChecker is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation; either version 2 of the License, or
 (at your option) any later version.

 CallChecker is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

 You should have received a copy of the GNU General Public License
 along with CallChecker; if not, write to the Free Software
 Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  US
 */

#import "CallController.h"
#import "Call.h"
#import "CallMonitor.h"
#import "Preferences.h"



@implementation CallController

- (id)initWithCall:(Call *)call {
    self = [self init];
    if(self && [NSBundle loadNibNamed:@"CallWindow" owner:self]) {
        NSString *name, *msg;
        NSString *dateFormat = [NSString stringWithFormat:@"%@  %@", [[NSUserDefaults standardUserDefaults] stringForKey:NSShortDateFormatString], [[NSUserDefaults standardUserDefaults] stringForKey:NSTimeFormatString]];
        _call = [call retain];
        dateFormatter = [[NSDateFormatter alloc] initWithDateFormat:dateFormat allowNaturalLanguage:NO];

        name = [CallMonitor nameForCallerID:[_call callerID]];

        if(name)
            msg = [NSString stringWithFormat:@"%@ (%@)", name, [_call callerID]];
        else
            msg = [NSString stringWithFormat:@"%@", [_call callerID]];

        if([Preferences reportForAllMSNs]
           || [Preferences numberOfActiveMSNs] != 1
           || ![Preferences isActiveMSN:[_call msn]]) {
            msg = [msg stringByAppendingString:[@" -> " stringByAppendingString:[Preferences aliasForMSN:[_call msn]]]];
        }
        [callField setStringValue:msg];
        [self displayRemoteTimestamp];

        [window makeKeyAndOrderFront:self];
        [window orderFrontRegardless];
        return self;
    }
    return nil;
}

- (void)dealloc {
    // window has "Release when closed" set so it must not be released manually
    [dateFormatter release];
    [_call release];
    [super dealloc];
}

- (void)windowWillClose:(NSNotification *)notification {
    [self autorelease];
}


#pragma mark ----- Action Handlers -----

- (IBAction)timestampAction:(id)sender {
    if(showsRemoteTimestamp) {
        [self displayLocalTimestamp];
    } else {
        [self displayRemoteTimestamp];
    }
}


#pragma mark ----- Date display -----

- (void)displayLocalTimestamp {
    [self displayDate:[_call timestamp] withPrefix:NSLocalizedString(@"System time:", @"System timestamp label")];
    showsRemoteTimestamp = NO;
}
- (void)displayRemoteTimestamp {
    [self displayDate:[_call date] withPrefix:NSLocalizedString(@"Time:", @"Router timestamp label")];
    showsRemoteTimestamp = YES;
}
- (void)displayDate:(NSCalendarDate *)date withPrefix:(NSString *)prefix {
    NSString *str;
    str = [dateFormatter stringForObjectValue:date];
    if(prefix)
        str = [NSString stringWithFormat:@"%@ %@", prefix, str];
    [dateField setStringValue:str];
}

@end
