//
//  Preferences.h
//  CallChecker
//
//  Created by Steffen Kamp on Mon Oct 19 2002.
//  <mailto:steffen@earthlingsoft.net>
//  Copyright (c) 2002 earthlingsoft. All rights reserved.
//

/*
 This file is part of CallChecker.

 CallChecker is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation; either version 2 of the License, or
 (at your option) any later version.

 CallChecker is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

 You should have received a copy of the GNU General Public License
 along with CallChecker; if not, write to the Free Software
 Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  US
 */


#import <Cocoa/Cocoa.h>

#define DEFAULTS [NSUserDefaults standardUserDefaults]

extern NSString *DefaultHost;
extern NSString *DefaultPort;
extern NSString *DefaultReportAll;
extern NSString *DefaultMSNAliases;
extern NSString *DefaultPollingInterval;
extern NSString *DefaultImondPort;

extern NSString *CCAliasMSNKey;
extern NSString *CCAliasNameKey;
extern NSString *CCAliasActiveKey;

extern NSString *CCHostDefaultsChangedNotification;

@interface Preferences : NSObject
{
    IBOutlet NSTableView *aliasTable;
    IBOutlet NSTextField *host;
    IBOutlet NSTextField *port;
    IBOutlet NSTextField *pollingInterval;
    IBOutlet NSTextField *imondPort;
    IBOutlet NSButton *removeAlias;
    IBOutlet NSButton *reportAll;
    IBOutlet NSButton *activateSettings;
    IBOutlet NSWindow *window;
}

+ (Preferences *)sharedPreferences;

- (IBAction)addAliasAction:(id)sender;
- (IBAction)removeAliasAction:(id)sender;
- (IBAction)reportAllAction:(id)sender;
- (IBAction)activateSettingsAction:(id)sender;
- (IBAction)showWindow:(id)sender;

- (void)registerDefaults;
- (void)updateHostDefaults;
- (void)fillInDefaults;

+ (BOOL)reportForAllMSNs;
+ (BOOL)reportForMSN:(NSString *)msn;
+ (int)numberOfActiveMSNs;

+ (NSString *)aliasForMSN:(NSString *)msn;
+ (BOOL)isActiveMSN:(NSString *)msn;
+ (NSDictionary *)aliasEntryForMSN:(NSString *)msn;

@end
