/*
 *  SocketConnect.m
 *  CallChecker
 *
 *  Created by Steffen Kamp on Sat Feb 08 2003.
 *  <mailto:steffen@earthlingsoft.net>
 *  Copyright (c) 2003 earthlingsoft. All rights reserved.
 *
 */

/*
 This file is part of CallChecker.

 CallChecker is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation; either version 2 of the License, or
 (at your option) any later version.

 CallChecker is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

 You should have received a copy of the GNU General Public License
 along with CallChecker; if not, write to the Free Software
 Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  US
 */

#include "SocketConnect.h"

#import <sys/socket.h>
#import <netinet/in.h>
#import <arpa/inet.h>
#import <unistd.h>
#import <sys/time.h>
#import <netdb.h>
#import <signal.h>

#undef debug

#define TIMEOUT 2

typedef void SignalFunctionType(int);


void connectAlarm(int signo) {
    return;
}

int connectedSocketForHostAndPort(NSString *addr, unsigned int port) {
    int sockfd;
    struct sockaddr_in dest_addr;   // will hold the destination addr
    struct timeval timeout;

    struct hostent *theHost;
    theHost = gethostbyname2([addr lossyCString], AF_INET);
    if(!theHost) {
#ifdef debug
        NSLog(@"'gethostbyname2()' failed: %i", h_errno);
#endif
        return NO;
    }

    char **inaddr = theHost->h_addr_list;
    if(nil == *inaddr) {
        NSLog(@"hostent from gethostbyname2() didn't contain ip");
        return NO;
    }

    dest_addr.sin_family = AF_INET;     // host byte order
    dest_addr.sin_port = htons(port);   // short, network byte order
    dest_addr.sin_addr.s_addr = *((in_addr_t *)*inaddr);

    memset(&(dest_addr.sin_zero), '\0', 8);  // zero the rest of the struct

    sockfd = socket(AF_INET, SOCK_STREAM, 0);
    if(sockfd == -1) {
        NSLog(@"'socket()' failed: %i", errno);
        return -1;
    }

    timeout.tv_sec = TIMEOUT;
    timeout.tv_usec = 0;
    // set short timout value
    if(setsockopt(sockfd, SOL_SOCKET, SO_RCVTIMEO, &timeout, sizeof(timeout)) < 0)
        NSLog(@"setsockopt1 failed");
    if(setsockopt(sockfd, SOL_SOCKET, SO_SNDTIMEO, &timeout, sizeof(timeout)) < 0)
        NSLog(@"setsockopt2 failed");

    unsigned int previousAlarmTime = alarm(TIMEOUT);
    SignalFunctionType *previousAlarmFunction = signal(SIGALRM, connectAlarm);

    if(connect(sockfd, (struct sockaddr *)&dest_addr, sizeof(struct sockaddr)) == -1) {
        signal(SIGALRM, previousAlarmFunction);
        alarm(previousAlarmTime);
#ifdef debug
        NSLog(@"'connect()' failed: %i", errno);
#endif
        close(sockfd);
        return -1;
    }

    signal(SIGALRM, previousAlarmFunction);
    alarm(previousAlarmTime);

    return sockfd;
}